@@ -1,7 +1,7 @@
 //! Program state processor
 
 use crate::{
-    state::governance::Governance,
+    state::governance::GovernanceV2,
     state::{
         enums::GovernanceAccountType,
         governance::{
@@ -9,7 +9,6 @@ use crate::{
             GovernanceConfig,
         },
         realm::get_realm_data,
-        token_owner_record::get_token_owner_record_data_for_realm,
     },
     tools::bpf_loader_upgradeable::{
         assert_program_upgrade_authority_is_signer, set_program_upgrade_authority,
@@ -22,6 +21,7 @@ use solana_program::{
     rent::Rent,
     sysvar::Sysvar,
 };
+
 use spl_governance_tools::account::create_and_serialize_account_signed;
 
 /// Processes CreateProgramGovernance instruction
@@ -47,45 +47,41 @@ pub fn process_create_program_governance(
 
     let system_info = next_account_info(account_info_iter)?; // 8
 
-    let rent_sysvar_info = next_account_info(account_info_iter)?; // 9
-    let rent = &Rent::from_account_info(rent_sysvar_info)?;
+    let rent = Rent::get()?;
 
-    let governance_authority_info = next_account_info(account_info_iter)?; // 10
+    let create_authority_info = next_account_info(account_info_iter)?; // 9
 
     assert_valid_create_governance_args(program_id, &config, realm_info)?;
 
     let realm_data = get_realm_data(program_id, realm_info)?;
-    let token_owner_record_data =
-        get_token_owner_record_data_for_realm(program_id, token_owner_record_info, realm_info.key)?;
 
-    token_owner_record_data.assert_token_owner_or_delegate_is_signer(governance_authority_info)?;
-
-    let voter_weight = token_owner_record_data.resolve_voter_weight(
+    realm_data.assert_create_authority_can_create_governance(
         program_id,
-        account_info_iter,
         realm_info.key,
-        &realm_data,
+        token_owner_record_info,
+        create_authority_info,
+        account_info_iter, // realm_config_info 10, voter_weight_record_info 11
     )?;
 
-    token_owner_record_data.assert_can_create_governance(&realm_data, voter_weight)?;
-
-    let program_governance_data = Governance {
-        account_type: GovernanceAccountType::ProgramGovernance,
+    let program_governance_data = GovernanceV2 {
+        account_type: GovernanceAccountType::ProgramGovernanceV2,
         realm: *realm_info.key,
         governed_account: *governed_program_info.key,
         config,
         proposals_count: 0,
-        reserved: [0; 8],
+        reserved: [0; 6],
+        voting_proposal_count: 0,
+        reserved_v2: [0; 128],
     };
 
-    create_and_serialize_account_signed::<Governance>(
+    create_and_serialize_account_signed::<GovernanceV2>(
         payer_info,
         program_governance_info,
         &program_governance_data,
         &get_program_governance_address_seeds(realm_info.key, governed_program_info.key),
         program_id,
         system_info,
-        rent,
+        &rent,
     )?;
 
     if transfer_upgrade_authority {
