@@ -8,18 +8,13 @@ use solana_program::{
     sysvar::Sysvar,
 };
 
-use crate::{
-    state::{
-        governance::get_governance_data_for_realm,
-        proposal::get_proposal_data_for_governance_and_governing_mint,
-        realm::get_realm_data_for_governing_token_mint,
-        token_owner_record::get_token_owner_record_data_for_proposal_owner,
-    },
-    tools::spl_token::get_spl_token_mint_supply,
+use crate::state::{
+    governance::get_governance_data_for_realm,
+    proposal::get_proposal_data_for_governance_and_governing_mint,
+    realm::get_realm_data_for_governing_token_mint,
+    token_owner_record::get_token_owner_record_data_for_proposal_owner,
 };
 
-use borsh::BorshSerialize;
-
 /// Processes FinalizeVote instruction
 pub fn process_finalize_vote(program_id: &Pubkey, accounts: &[AccountInfo]) -> ProgramResult {
     let account_info_iter = &mut accounts.iter();
@@ -31,15 +26,14 @@ pub fn process_finalize_vote(program_id: &Pubkey, accounts: &[AccountInfo]) -> P
 
     let governing_token_mint_info = next_account_info(account_info_iter)?; // 4
 
-    let clock_info = next_account_info(account_info_iter)?; // 5
-    let clock = Clock::from_account_info(clock_info)?;
+    let clock = Clock::get()?;
 
-    let realm_data = get_realm_data_for_governing_token_mint(
+    let mut realm_data = get_realm_data_for_governing_token_mint(
         program_id,
         realm_info,
         governing_token_mint_info.key,
     )?;
-    let governance_data =
+    let mut governance_data =
         get_governance_data_for_realm(program_id, governance_info, realm_info.key)?;
 
     let mut proposal_data = get_proposal_data_for_governance_and_governing_mint(
@@ -49,12 +43,20 @@ pub fn process_finalize_vote(program_id: &Pubkey, accounts: &[AccountInfo]) -> P
         governing_token_mint_info.key,
     )?;
 
-    let governing_token_mint_supply = get_spl_token_mint_supply(governing_token_mint_info)?;
+    let realm_config_info = next_account_info(account_info_iter)?; // 5
+
+    let max_voter_weight = proposal_data.resolve_max_voter_weight(
+        program_id,
+        realm_config_info,
+        governing_token_mint_info,
+        account_info_iter, // *6
+        realm_info.key,
+        &realm_data,
+    )?;
 
     proposal_data.finalize_vote(
-        governing_token_mint_supply,
+        max_voter_weight,
         &governance_data.config,
-        &realm_data,
         clock.unix_timestamp,
     )?;
 
@@ -69,5 +71,13 @@ pub fn process_finalize_vote(program_id: &Pubkey, accounts: &[AccountInfo]) -> P
 
     proposal_data.serialize(&mut *proposal_info.data.borrow_mut())?;
 
+    // Update Realm voting_proposal_count
+    realm_data.voting_proposal_count = realm_data.voting_proposal_count.saturating_sub(1);
+    realm_data.serialize(&mut *realm_info.data.borrow_mut())?;
+
+    // Update  Governance voting_proposal_count
+    governance_data.voting_proposal_count = governance_data.voting_proposal_count.saturating_sub(1);
+    governance_data.serialize(&mut *governance_info.data.borrow_mut())?;
+
     Ok(())
 }
