@@ -1,14 +1,15 @@
 use solana_program::{instruction::Instruction, pubkey::Pubkey};
 use solana_sdk::signature::Keypair;
-use spl_governance::{
-    addins::voter_weight::VoterWeightRecord,
-    state::{
-        governance::Governance, proposal::ProposalV2, proposal_instruction::ProposalInstructionV2,
-        realm::Realm, realm_config::RealmConfigAccount, signatory_record::SignatoryRecord,
-        token_owner_record::TokenOwnerRecord, vote_record::VoteRecordV2,
-    },
+use spl_governance::state::{
+    governance::GovernanceV2, native_treasury::NativeTreasury, program_metadata::ProgramMetadata,
+    proposal::ProposalV2, proposal_transaction::ProposalTransactionV2, realm::RealmV2,
+    realm_config::RealmConfigAccount, signatory_record::SignatoryRecordV2,
+    token_owner_record::TokenOwnerRecordV2, vote_record::VoteRecordV2,
 };
 
+use spl_governance_addin_api::{
+    max_voter_weight::MaxVoterWeightRecord, voter_weight::VoterWeightRecord,
+};
 use spl_governance_test_sdk::tools::clone_keypair;
 
 pub trait AccountCookie {
@@ -19,7 +20,7 @@ pub trait AccountCookie {
 pub struct RealmCookie {
     pub address: Pubkey,
 
-    pub account: Realm,
+    pub account: RealmV2,
 
     pub community_mint_authority: Keypair,
 
@@ -44,7 +45,7 @@ pub struct RealmConfigCookie {
 pub struct TokenOwnerRecordCookie {
     pub address: Pubkey,
 
-    pub account: TokenOwnerRecord,
+    pub account: TokenOwnerRecordV2,
 
     pub token_source: Pubkey,
 
@@ -57,6 +58,9 @@ pub struct TokenOwnerRecordCookie {
     pub governance_delegate: Keypair,
 
     pub voter_weight_record: Option<VoterWeightRecordCookie>,
+
+    // This doesn't belong to TokenOwnerRecord and I put it here for simplicity for now
+    pub max_voter_weight_record: Option<MaxVoterWeightRecordCookie>,
 }
 
 impl TokenOwnerRecordCookie {
@@ -127,7 +131,7 @@ impl AccountCookie for GovernedAccountCookie {
 #[derive(Debug)]
 pub struct GovernanceCookie {
     pub address: Pubkey,
-    pub account: Governance,
+    pub account: GovernanceV2,
     pub next_proposal_index: u32,
 }
 
@@ -136,13 +140,14 @@ pub struct ProposalCookie {
     pub address: Pubkey,
     pub account: ProposalV2,
 
+    pub realm: Pubkey,
     pub proposal_owner: Pubkey,
 }
 
 #[derive(Debug)]
 pub struct SignatoryRecordCookie {
     pub address: Pubkey,
-    pub account: SignatoryRecord,
+    pub account: SignatoryRecordV2,
     pub signatory: Keypair,
 }
 
@@ -153,9 +158,9 @@ pub struct VoteRecordCookie {
 }
 
 #[derive(Debug)]
-pub struct ProposalInstructionCookie {
+pub struct ProposalTransactionCookie {
     pub address: Pubkey,
-    pub account: ProposalInstructionV2,
+    pub account: ProposalTransactionV2,
     pub instruction: Instruction,
 }
 
@@ -164,3 +169,21 @@ pub struct VoterWeightRecordCookie {
     pub address: Pubkey,
     pub account: VoterWeightRecord,
 }
+
+#[derive(Debug, Clone)]
+pub struct MaxVoterWeightRecordCookie {
+    pub address: Pubkey,
+    pub account: MaxVoterWeightRecord,
+}
+
+#[derive(Debug, Clone)]
+pub struct ProgramMetadataCookie {
+    pub address: Pubkey,
+    pub account: ProgramMetadata,
+}
+
+#[derive(Debug, Clone)]
+pub struct NativeTreasuryCookie {
+    pub address: Pubkey,
+    pub account: NativeTreasury,
+}
